aboutsummaryrefslogtreecommitdiff
path: root/src/fs/gnunet-service-fs.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/fs/gnunet-service-fs.h')
-rw-r--r--src/fs/gnunet-service-fs.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/src/fs/gnunet-service-fs.h b/src/fs/gnunet-service-fs.h
index 0c796bf..3213712 100644
--- a/src/fs/gnunet-service-fs.h
+++ b/src/fs/gnunet-service-fs.h
@@ -119,7 +119,7 @@ struct GetMessage
/**
* Which of the optional hash codes are present at the end of the
* message? See GET_MESSAGE_BIT_xx constants. For each bit that is
- * set, an additional GNUNET_HashCode with the respective content
+ * set, an additional struct GNUNET_HashCode with the respective content
* (in order of the bits) will be appended to the end of the GET
* message.
*/
@@ -129,7 +129,7 @@ struct GetMessage
* Hashcodes of the file(s) we're looking for.
* Details depend on the query type.
*/
- GNUNET_HashCode query;
+ struct GNUNET_HashCode query;
/* this is followed by hash codes as specified in the "hash_bitmap";
* after that, an optional bloomfilter (with bits set for replies
@@ -183,10 +183,9 @@ struct GSF_LocalClient;
struct GSF_RequestPlan;
/**
* DLL of request plans a particular pending request is
* involved with.
*/
-struct GSF_RequestPlanReference;
+struct GSF_PendingRequestPlanBijection;
/**
* Our connection to the datastore.
@@ -259,6 +258,12 @@ extern struct GNUNET_BLOCK_Context *GSF_block_ctx;
extern int GSF_enable_randomized_delays;
/**
+ * Size of the datastore queue we assume for common requests.
+ */
+extern unsigned int GSF_datastore_queue_size;
+
+
+/**
* Test if the DATABASE (GET) load on this peer is too high
* to even consider processing the query at
* all.
@@ -183,10 +183,9 @@ struct GSF_LocalClient;
struct GSF_RequestPlan;
/**
- * DLL of request plans a particular pending request is
- * involved with.
+ * Bijection between request plans and pending requests.
*/